@@ -21,9 +21,13 @@
 
 class CPassBox extends CInput {
 
-	public function __construct($name = 'password', $value = '', $size = 50, $maxlength = 255) {
+	public function __construct($name = 'password', $value = '', $maxlength = 255) {
 		parent::__construct('password', $name, $value);
-		$this->setAttribute('size', $size);
 		$this->setAttribute('maxlength', $maxlength);
 	}
+
+	public function setWidth($value) {
+		$this->addStyle('width: '.$value.'px;');
+		return $this;
+	}
 }
