@@ -124,7 +124,7 @@ class CScreenBuilder {
 		if (!empty($options['screen'])) {
 			$this->screen = $options['screen'];
 		}
-		elseif (!empty($options['screenid'])) {
+		elseif (array_key_exists('screenid', $options) && $options['screenid'] > 0) {
 			$this->screen = API::Screen()->get([
 				'screenids' => $options['screenid'],
 				'output' => API_OUTPUT_EXTEND,
@@ -169,31 +169,33 @@ class CScreenBuilder {
 	 * @return CScreenBase
 	 */
 	public static function getScreen(array $options = []) {
-		// get resourcetype from screenitem
-		if (empty($options['screenitem']) && !empty($options['screenitemid'])) {
-			if (!empty($options['hostid'])) {
-				$options['screenitem'] = API::TemplateScreenItem()->get([
-					'screenitemids' => $options['screenitemid'],
-					'hostids' => $options['hostid'],
-					'output' => API_OUTPUT_EXTEND
-				]);
+		if (!array_key_exists('resourcetype', $options)) {
+			$options['resourcetype'] = null;
+
+			// get resourcetype from screenitem
+			if (!array_key_exists('screenitem', $options) && array_key_exists('screenitemid', $options)) {
+				if (array_key_exists('hostid', $options) && $options['hostid'] > 0) {
+					$options['screenitem'] = API::TemplateScreenItem()->get([
+						'screenitemids' => $options['screenitemid'],
+						'hostids' => $options['hostid'],
+						'output' => API_OUTPUT_EXTEND
+					]);
+				}
+				else {
+					$options['screenitem'] = API::ScreenItem()->get([
+						'screenitemids' => $options['screenitemid'],
+						'output' => API_OUTPUT_EXTEND
+					]);
+				}
+				$options['screenitem'] = reset($options['screenitem']);
 			}
-			else {
-				$options['screenitem'] = API::ScreenItem()->get([
-					'screenitemids' => $options['screenitemid'],
-					'output' => API_OUTPUT_EXTEND
-				]);
+
+			if (array_key_exists('screenitem', $options) && array_key_exists('resourcetype', $options['screenitem'])) {
+				$options['resourcetype'] = $options['screenitem']['resourcetype'];
 			}
-			$options['screenitem'] = reset($options['screenitem']);
 		}
 
-		if (zbx_empty($options['resourcetype'])
-				&& array_key_exists('screenitem', $options)
-				&& !zbx_empty($options['screenitem']['resourcetype'])) {
-			$options['resourcetype'] = $options['screenitem']['resourcetype'];
-		}
-
-		if (zbx_empty($options['resourcetype'])) {
+		if ($options['resourcetype'] === null) {
 			return null;
 		}
 
@@ -252,22 +254,6 @@ class CScreenBuilder {
 				return new CScreenHostTriggers($options);
 
 			case SCREEN_RESOURCE_HISTORY:
-				// TODO: pass the items from the outside instead of retrieving them by ids
-				if (isset($options['itemids'])) {
-					$items = API::Item()->get([
-						'itemids' => $options['itemids'],
-						'webitems' => true,
-						'selectHosts' => ['name'],
-						'output' => ['itemid', 'hostid', 'name', 'key_', 'value_type', 'valuemapid'],
-						'preservekeys' => true
-					]);
-
-					$items = CMacrosResolverHelper::resolveItemNames($items);
-
-					$options['items'] = $items;
-					unset($options['itemids']);
-				}
-
 				return new CScreenHistory($options);
 
 			case SCREEN_RESOURCE_CHART:
@@ -284,6 +270,12 @@ class CScreenBuilder {
 			case SCREEN_RESOURCE_HTTPTEST_DETAILS:
 				return new CScreenHttpTestDetails($options);
 
+			case SCREEN_RESOURCE_DISCOVERY:
+				return new CScreenDiscovery($options);
+
+			case SCREEN_RESOURCE_HTTPTEST:
+				return new CScreenHttpTest($options);
+
 			default:
 				return null;
 		}
@@ -297,10 +289,10 @@ class CScreenBuilder {
 	 * @return array
 	 */
 	protected static function appendTemplatedScreenOption(array $options) {
-		if (isset($options['screen'])) {
+		if (array_key_exists('screen', $options)) {
 			$options['isTemplatedScreen'] = (bool) $options['screen']['templateid'];
 		}
-		elseif (isset($options['screenid'])) {
+		elseif (array_key_exists('screenid', $options) && $options['screenid'] > 0) {
 			$options['isTemplatedScreen'] = (bool) API::TemplateScreen()->get([
 				'screenids' => [$options['screenid']],
 				'output' => []
@@ -354,25 +346,38 @@ class CScreenBuilder {
 			$newColumns = [(new CCol())->addClass(ZBX_STYLE_CELL_WIDTH)];
 
 			for ($i = 0, $size = $this->screen['hsize']; $i < $size; $i++) {
-				$newColumns[] = (new CCol(
-					(new CDiv('+'))
+				if ($this->screen['hsize'] >= SCREEN_MAX_SIZE) {
+					$link = (new CDiv('+'))
 						->addClass(ZBX_STYLE_TREEVIEW_PLUS)
-						->onClick('javascript: location.href = "screenedit.php?config=1'.
-							'&screenid='.$this->screen['screenid'].url_param('templateid').'&add_col='.$i.'";'
-						)
-				))
+						->addClass(ZBX_STYLE_DISABLED);
+				}
+				else {
+					$link = (new CLink('+', 'screenedit.php?screenid='.$this->screen['screenid'].
+						url_param('templateid').'&add_col='.$i
+					))
+						->addClass(ZBX_STYLE_TREEVIEW_PLUS)
+						->addSID();
+				}
+
+				$newColumns[] = (new CCol($link))
 					->addClass(ZBX_STYLE_CENTER)
 					->addClass(ZBX_STYLE_MIDDLE);
 			}
 
-			$newColumns[] = (new CCol(
-				(new CDiv('+'))
+			if ($this->screen['hsize'] >= SCREEN_MAX_SIZE) {
+				$link = (new CDiv('+'))
 					->addClass(ZBX_STYLE_TREEVIEW_PLUS)
-					->onClick('javascript: location.href = "screenedit.php?config=1'.
-						'&screenid='.$this->screen['screenid'].url_param('templateid').
-						'&add_col='.$this->screen['hsize'].'";'
-					)
-			))
+					->addClass(ZBX_STYLE_DISABLED);
+			}
+			else {
+				$link = (new CLink('+', 'screenedit.php?screenid='.$this->screen['screenid'].url_param('templateid').
+					'&add_col='.$this->screen['hsize']
+				))
+					->addClass(ZBX_STYLE_TREEVIEW_PLUS)
+					->addSID();
+			}
+
+			$newColumns[] = (new CCol($link))
 				->addClass(ZBX_STYLE_CENTER)
 				->addClass(ZBX_STYLE_MIDDLE)
 				->addClass(ZBX_STYLE_CELL_WIDTH);
@@ -386,13 +391,20 @@ class CScreenBuilder {
 
 			// action left cell
 			if ($this->mode == SCREEN_MODE_EDIT) {
-				$newColumns[] = (new CCol(
-					(new CDiv('+'))
+				if ($this->screen['vsize'] >= SCREEN_MAX_SIZE) {
+					$link = (new CDiv('+'))
 						->addClass(ZBX_STYLE_TREEVIEW_PLUS)
-						->onClick('javascript: location.href = "screenedit.php?config=1'.
-							'&screenid='.$this->screen['screenid'].url_param('templateid').'&add_row='.$r.'";'
-						)
-				))
+						->addClass(ZBX_STYLE_DISABLED);
+				}
+				else {
+					$link = (new CLink('+', 'screenedit.php?screenid='.$this->screen['screenid'].
+						url_param('templateid').'&add_row='.$r
+					))
+						->addClass(ZBX_STYLE_TREEVIEW_PLUS)
+						->addSID();
+				}
+
+				$newColumns[] = (new CCol($link))
 					->addClass(ZBX_STYLE_CENTER)
 					->addClass(ZBX_STYLE_MIDDLE);
 			}
@@ -434,7 +446,7 @@ class CScreenBuilder {
 
 				if (!empty($screenitem['screenitemid'])) {
 					$emptyScreenRow = false;
-					$emptyScreenColumns[$c] = 1;
+					$emptyScreenColumns[$c] = true;
 				}
 
 				// action
@@ -541,23 +553,23 @@ class CScreenBuilder {
 
 			// action right cell
 			if ($this->mode == SCREEN_MODE_EDIT) {
-				if ($emptyScreenRow) {
-					$removeRowLink = 'javascript: location.href = "screenedit.php?screenid='.$this->screen['screenid'].
-						url_param('templateid').'&rmv_row='.$r.'";';
+				if ($this->screen['vsize'] == SCREEN_MIN_SIZE) {
+					$link = (new CDiv('−'))
+						->addClass(ZBX_STYLE_TREEVIEW_PLUS)
+						->addClass(ZBX_STYLE_DISABLED);
 				}
 				else {
-					$removeRowLink = 'javascript:'.
-						' if (confirm('.CJs::encodeJson(_('This screen-row is not empty. Delete it?')).')) {'.
-							' location.href = "screenedit.php?screenid='.$this->screen['screenid'].
-							url_param('templateid').'&rmv_row='.$r.'";'.
-						' }';
+					$link = (new CLink('−', 'screenedit.php?screenid='.$this->screen['screenid'].
+						url_param('templateid').'&rmv_row='.$r
+					))
+						->addClass(ZBX_STYLE_TREEVIEW_PLUS)
+						->addSID();
+					if (!$emptyScreenRow) {
+						$link->addConfirmation(CJs::encodeJson(_('This screen-row is not empty. Delete it?')));
+					}
 				}
 
-				$newColumns[] = (new CCol(
-					(new CDiv('−'))
-						->addClass(ZBX_STYLE_TREEVIEW_PLUS)
-						->onClick($removeRowLink)
-				))
+				$newColumns[] = (new CCol($link))
 					->addClass(ZBX_STYLE_CENTER)
 					->addClass(ZBX_STYLE_MIDDLE);
 			}
@@ -566,37 +578,44 @@ class CScreenBuilder {
 
 		// action bottom row
 		if ($this->mode == SCREEN_MODE_EDIT) {
-			$newColumns = [
-				(new CCol(
-					(new CDiv('+'))
-						->addClass(ZBX_STYLE_TREEVIEW_PLUS)
-						->onClick('javascript: location.href = "screenedit.php'.
-							'?screenid='.$this->screen['screenid'].url_param('templateid').
-							'&add_row='.$this->screen['vsize'].'";'
-						)
+			if ($this->screen['vsize'] >= SCREEN_MAX_SIZE) {
+				$link = (new CDiv('+'))
+					->addClass(ZBX_STYLE_TREEVIEW_PLUS)
+					->addClass(ZBX_STYLE_DISABLED);
+			}
+			else {
+				$link = (new CLink('+', 'screenedit.php?screenid='.$this->screen['screenid'].url_param('templateid').
+					'&add_row='.$this->screen['vsize']
 				))
+					->addClass(ZBX_STYLE_TREEVIEW_PLUS)
+					->addSID();
+			}
+
+			$newColumns = [
+				(new CCol($link))
 					->addClass(ZBX_STYLE_CENTER)
 					->addClass(ZBX_STYLE_MIDDLE)
 			];
 
 			for ($i = 0; $i < $this->screen['hsize']; $i++) {
-				if (isset($emptyScreenColumns[$i])) {
-					$removeColumnLink = 'javascript:'.
-						' if (confirm('.CJs::encodeJson(_('This screen-column is not empty. Delete it?')).')) {'.
-							' location.href = "screenedit.php?screenid='.$this->screen['screenid'].
-								url_param('templateid').'&rmv_col='.$i.'";'.
-						' }';
+				if ($this->screen['hsize'] == SCREEN_MIN_SIZE) {
+					$link = (new CDiv('−'))
+						->addClass(ZBX_STYLE_TREEVIEW_PLUS)
+						->addClass(ZBX_STYLE_DISABLED);
 				}
 				else {
-					$removeColumnLink = 'javascript: location.href = "screenedit.php?config=1'.
-						'&screenid='.$this->screen['screenid'].url_param('templateid').'&rmv_col='.$i.'";';
+					$link = (new CLink('−', 'screenedit.php?screenid='.$this->screen['screenid'].
+						url_param('templateid').'&rmv_col='.$i
+					))
+						->addClass(ZBX_STYLE_TREEVIEW_PLUS)
+						->addSID();
+
+					if (array_key_exists($i, $emptyScreenColumns)) {
+						$link->addConfirmation(CJs::encodeJson(_('This screen-column is not empty. Delete it?')));
+					}
 				}
 
-				$newColumns[] = (new CCol(
-					(new CDiv('−'))
-						->addClass(ZBX_STYLE_TREEVIEW_PLUS)
-						->onClick($removeColumnLink)
-				))
+				$newColumns[] = (new CCol($link))
 					->addClass(ZBX_STYLE_CENTER)
 					->addClass(ZBX_STYLE_MIDDLE);
 			}
