@@ -14,7 +14,7 @@
 		});
 
 		jQuery('#algorithm').change(function() {
-			var statusDisabled = (jQuery(this).val() == <?php echo SERVICE_ALGORITHM_NONE ?>);
+			var statusDisabled = (jQuery(this).val() == <?= SERVICE_ALGORITHM_NONE ?>);
 			jQuery('#showsla, #trigger, #btn1, #goodsla').prop('disabled', statusDisabled);
 
 			if (!statusDisabled) {
@@ -77,20 +77,15 @@
 
 			// column "action"
 			var td = document.createElement('td');
-			var inputRemove = document.createElement('input');
-			inputRemove.setAttribute('type', 'button');
-			inputRemove.setAttribute('value', <?php echo CJs::encodeJson(_('Remove')); ?>);
-			inputRemove.setAttribute('class', 'link_menu');
+			td.setAttribute('class', '<?= ZBX_STYLE_NOWRAP ?>');
+			var inputRemove = document.createElement('button');
+			inputRemove.setAttribute('class', '<?= ZBX_STYLE_BTN_LINK ?>');
 			inputRemove.setAttribute('onclick', 'javascript: removeDependentChild(\'' + serviceid + '\');');
+			inputRemove.appendChild(document.createTextNode(<?= CJs::encodeJson(_('Remove')) ?>));
 
 			td.appendChild(inputRemove);
 			tr.appendChild(td);
 			document.getElementById('service_children').firstChild.appendChild(tr);
-			jQuery('#service_children .message').css('display', 'none');
-
-			if (IE8) {
-				jQuery('#service_children').parent().addClass('ie8fix-inline').removeClass('ie8fix-inline');
-			}
 		}
 	}
 
@@ -99,10 +94,6 @@
 		removeObjectById('children_' + serviceid + '_name');
 		removeObjectById('children_' + serviceid + '_serviceid');
 		removeObjectById('children_' + serviceid + '_trigger');
-
-		if (IE8) {
-			jQuery('#service_children').parent().addClass('ie8fix-inline').removeClass('ie8fix-inline');
-		}
 	}
 
 	function removeTime(id) {
@@ -113,9 +104,5 @@
 		removeObjectById('times_' + id + '_from');
 		removeObjectById('times_' + id + '_to');
 		removeObjectById('times_' + id + '_note');
-
-		if (IE8) {
-			parent.closest('table').addClass('ie8fix-inline').removeClass('ie8fix-inline');
-		}
 	}
 </script>
