@@ -20,24 +20,91 @@
 #include "common.h"
 
 #include "zbxdb.h"
+
+#if defined(HAVE_IBM_DB2)
+#	include <sqlcli1.h>
+#elif defined(HAVE_MYSQL)
+#	include "mysql.h"
+#	include "errmsg.h"
+#	include "mysqld_error.h"
+#elif defined(HAVE_ORACLE)
+#	include "oci.h"
+#elif defined(HAVE_POSTGRESQL)
+#	include <libpq-fe.h>
+#elif defined(HAVE_SQLITE3)
+#	include <sqlite3.h>
+#endif
+
 #include "dbschema.h"
 #include "log.h"
 #if defined(HAVE_SQLITE3)
 #	include "mutexs.h"
 #endif
 
+struct zbx_db_result
+{
+#if defined(HAVE_IBM_DB2)
+	SQLHANDLE	hstmt;
+	SQLSMALLINT	nalloc;
+	SQLSMALLINT	ncolumn;
+	DB_ROW		values;
+	DB_ROW		values_cli;
+	SQLINTEGER	*values_len;
+#elif defined(HAVE_MYSQL)
+	MYSQL_RES	*result;
+#elif defined(HAVE_ORACLE)
+	OCIStmt		*stmthp;	/* the statement handle for select operations */
+	int 		ncolumn;
+	DB_ROW		values;
+	ub4		*values_alloc;
+	OCILobLocator	**clobs;
+#elif defined(HAVE_POSTGRESQL)
+	PGresult	*pg_result;
+	int		row_num;
+	int		fld_num;
+	int		cursor;
+	DB_ROW		values;
+#elif defined(HAVE_SQLITE3)
+	int		curow;
+	char		**data;
+	int		nrow;
+	int		ncolumn;
+	DB_ROW		values;
+#endif
+};
+
 static int	txn_level = 0;	/* transaction level, nested transactions are not supported */
 static int	txn_error = 0;	/* failed transaction */
 
 extern int	CONFIG_LOG_SLOW_QUERIES;
 
 #if defined(HAVE_IBM_DB2)
+typedef struct
+{
+	SQLHANDLE	henv;
+	SQLHANDLE	hdbc;
+}
+zbx_ibm_db2_handle_t;
+
 static zbx_ibm_db2_handle_t	ibm_db2;
 
-void	zbx_ibm_db2_log_errors(SQLSMALLINT htype, SQLHANDLE hndl, zbx_err_codes_t err, const char *context);
+static int	IBM_DB2server_status();
+static int	zbx_ibm_db2_success(SQLRETURN ret);
+static int	zbx_ibm_db2_success_ext(SQLRETURN ret);
+static void	zbx_ibm_db2_log_errors(SQLSMALLINT htype, SQLHANDLE hndl, zbx_err_codes_t err, const char *context);
 #elif defined(HAVE_MYSQL)
 static MYSQL			*conn = NULL;
 #elif defined(HAVE_ORACLE)
+typedef struct
+{
+	OCIEnv		*envhp;
+	OCIError	*errhp;
+	OCISvcCtx	*svchp;
+	OCIServer	*srvhp;
+	OCIStmt		*stmthp;	/* the statement handle for execute operations */
+}
+zbx_oracle_db_handle_t;
+
 static zbx_oracle_db_handle_t	oracle;
 
 /* 64-bit integer binding is supported only starting with Oracle 11.2 */
@@ -47,6 +114,8 @@ static OCINumber	**oci_ids = NULL;
 static int		oci_ids_alloc = 0;
 static int		oci_ids_num = 0;
 
+static ub4	OCI_DBserver_status();
+
 #elif defined(HAVE_POSTGRESQL)
 static PGconn			*conn = NULL;
 static int			ZBX_PG_BYTEAOID = 0;
@@ -333,6 +402,10 @@ int	zbx_db_connect(char *host, char *user, char *password, char *dbname, char *d
 	if (0 != mysql_options(conn, MYSQL_OPT_RECONNECT, &mysql_reconnect))
 		zabbix_log(LOG_LEVEL_WARNING, "Cannot set MySQL reconnect option.");
 
+	/* in contrast to "set names utf8" results of this call will survive auto-reconnects */
+	if (0 != mysql_set_character_set(conn, "utf8"))
+		zabbix_log(LOG_LEVEL_WARNING, "cannot set MySQL character set to \"utf8\"");
+
 	if (ZBX_DB_OK == ret && 0 != mysql_select_db(conn, dbname))
 	{
 		zabbix_errlog(ERR_Z3001, dbname, mysql_errno(conn), mysql_error(conn));
@@ -342,12 +415,6 @@ int	zbx_db_connect(char *host, char *user, char *password, char *dbname, char *d
 	if (ZBX_DB_FAIL == ret && SUCCEED == is_recoverable_mysql_error())
 		ret = ZBX_DB_DOWN;
 
-	if (ZBX_DB_OK == ret)
-	{
-		if (0 < (ret = zbx_db_execute("%s", "set names utf8")))
-			ret = ZBX_DB_OK;
-	}
-
 #elif defined(HAVE_ORACLE)
 #if defined(HAVE_GETENV) && defined(HAVE_PUTENV)
 	if (NULL == getenv("NLS_LANG"))
@@ -1096,12 +1163,15 @@ int	zbx_db_vexecute(const char *fmt, va_list args)
 					zabbix_log(LOG_LEVEL_DEBUG, "cannot retrieve result set");
 					break;
 				}
-				else
-					ret += (int)mysql_affected_rows(conn);
 
-				/* more results? -1 = no, >0 = error, 0 = yes (keep looping) */
+				ret += (int)mysql_affected_rows(conn);
+
+				/* more results? 0 = yes (keep looping), -1 = no, >0 = error */
 				if (0 < (status = mysql_next_result(conn)))
+				{
 					zabbix_errlog(ERR_Z3005, mysql_errno(conn), mysql_error(conn), sql);
+					ret = (SUCCEED == is_recoverable_mysql_error() ? ZBX_DB_DOWN : ZBX_DB_FAIL);
+				}
 			}
 			while (0 == status);
 		}
@@ -1236,8 +1306,8 @@ DB_RESULT	zbx_db_vselect(const char *fmt, va_list args)
 	zabbix_log(LOG_LEVEL_DEBUG, "query [txnlev:%d] [%s]", txn_level, sql);
 
 #if defined(HAVE_IBM_DB2)
-	result = zbx_malloc(result, sizeof(ZBX_IBM_DB2_RESULT));
-	memset(result, 0, sizeof(ZBX_IBM_DB2_RESULT));
+	result = zbx_malloc(result, sizeof(struct zbx_db_result));
+	memset(result, 0, sizeof(struct zbx_db_result));
 
 	/* allocate a statement handle */
 	if (SUCCEED != zbx_ibm_db2_success(ret = SQLAllocHandle(SQL_HANDLE_STMT, ibm_db2.hdbc, &result->hstmt)))
@@ -1287,14 +1357,19 @@ error:
 		zbx_ibm_db2_log_errors(SQL_HANDLE_DBC, ibm_db2.hdbc, ERR_Z3005, sql);
 		zbx_ibm_db2_log_errors(SQL_HANDLE_STMT, result->hstmt, ERR_Z3005, sql);
 
-		IBM_DB2free_result(result);
+		DBfree_result(result);
 
 		result = (SQL_CD_TRUE == IBM_DB2server_status() ? NULL : (DB_RESULT)ZBX_DB_DOWN);
 	}
 #elif defined(HAVE_MYSQL)
+	result = zbx_malloc(NULL, sizeof(struct zbx_db_result));
+	result->result = NULL;
+
 	if (NULL == conn)
 	{
 		zabbix_errlog(ERR_Z3003);
+
+		DBfree_result(result);
 		result = NULL;
 	}
 	else
@@ -1303,14 +1378,15 @@ error:
 		{
 			zabbix_errlog(ERR_Z3005, mysql_errno(conn), mysql_error(conn), sql);
 
+			DBfree_result(result);
 			result = (SUCCEED == is_recoverable_mysql_error() ? (DB_RESULT)ZBX_DB_DOWN : NULL);
 		}
 		else
-			result = mysql_store_result(conn);
+			result->result = mysql_store_result(conn);
 	}
 #elif defined(HAVE_ORACLE)
-	result = zbx_malloc(NULL, sizeof(ZBX_OCI_DB_RESULT));
-	memset(result, 0, sizeof(ZBX_OCI_DB_RESULT));
+	result = zbx_malloc(NULL, sizeof(struct zbx_db_result));
+	memset(result, 0, sizeof(struct zbx_db_result));
 
 	err = OCIHandleAlloc((dvoid *)oracle.envhp, (dvoid **)&result->stmthp, OCI_HTYPE_STMT, (size_t)0, (dvoid **)0);
 
@@ -1449,12 +1525,12 @@ error:
 		int	server_status;
 
 		server_status = OCI_handle_sql_error(ERR_Z3005, err, sql);
-		OCI_DBfree_result(result);
+		DBfree_result(result);
 
 		result = (ZBX_DB_DOWN == server_status ? (DB_RESULT)(intptr_t)server_status : NULL);
 	}
 #elif defined(HAVE_POSTGRESQL)
-	result = zbx_malloc(NULL, sizeof(ZBX_PG_DB_RESULT));
+	result = zbx_malloc(NULL, sizeof(struct zbx_db_result));
 	result->pg_result = PQexec(conn, sql);
 	result->values = NULL;
 	result->cursor = 0;
@@ -1471,7 +1547,7 @@ error:
 		zabbix_errlog(ERR_Z3005, 0, error, sql);
 		zbx_free(error);
 
-		PG_DBfree_result(result);
+		DBfree_result(result);
 		result = (CONNECTION_OK == PQstatus(conn) ? NULL : (DB_RESULT)ZBX_DB_DOWN);
 	}
 	else	/* init rownum */
@@ -1480,7 +1556,7 @@ error:
 	if (0 == txn_level)
 		zbx_mutex_lock(&sqlite_access);
 
-	result = zbx_malloc(NULL, sizeof(ZBX_SQ_DB_RESULT));
+	result = zbx_malloc(NULL, sizeof(struct zbx_db_result));
 	result->curow = 0;
 
 lbl_get_table:
@@ -1492,7 +1568,7 @@ lbl_get_table:
 		zabbix_errlog(ERR_Z3005, 0, error, sql);
 		sqlite3_free(error);
 
-		SQ_DBfree_result(result);
+		DBfree_result(result);
 
 		switch (ret)
 		{
@@ -1549,68 +1625,6 @@ DB_RESULT	zbx_db_select_n(const char *query, int n)
 }
 
 #ifdef HAVE_POSTGRESQL
-/******************************************************************************
- *                                                                            *
- * Function: zbx_db_bytea_escape                                              *
- *                                                                            *
- * Purpose: converts from binary string to the null terminated escaped string *
- *                                                                            *
- * Transformations:                                                           *
- *      <= 0x1f || '\'' || '\\' || >= 0x7f -> \\ooo (ooo is an octal number)  *
- *                                                                            *
- * Parameters:                                                                *
- *      input - null terminated hexadecimal string                            *
- *      output - pointer to buffer                                            *
- *      olen - size of returned buffer                                        *
- *                                                                            *
- ******************************************************************************/
-size_t	zbx_db_bytea_escape(const u_char *input, size_t ilen, char **output, size_t *olen)
-{
-	const u_char	*i = input;
-	char		*o;
-	size_t		len = 1;	/* '\0' */
-
-	while (i - input < ilen)
-	{
-		if (0x1f >= *i || '\'' == *i || '\\' == *i || 0x7f <= *i)
-		{
-			if (1 == ZBX_PG_ESCAPE_BACKSLASH)
-				len++;
-			len += 4;
-		}
-		else
-			len++;
-		i++;
-	}
-
-	if (*olen < len)
-	{
-		*olen = len;
-		*output = zbx_realloc(*output, *olen);
-	}
-	o = *output;
-	i = input;
-
-	while (i - input < ilen)
-	{
-		if (0x1f >= *i || '\'' == *i || '\\' == *i || 0x7f <= *i)
-		{
-			if (1 == ZBX_PG_ESCAPE_BACKSLASH)
-				*o++ = '\\';
-			*o++ = '\\';
-			*o++ = ((*i >> 6) & 0x7) + 0x30;
-			*o++ = ((*i >> 3) & 0x7) + 0x30;
-			*o++ = (*i & 0x7) + 0x30;
-		}
-		else
-			*o++ = *i;
-		i++;
-	}
-	*o = '\0';
-
-	return len - 1;
-}
-
 /******************************************************************************
  *                                                                            *
  * Function: zbx_db_bytea_unescape                                            *
@@ -1685,7 +1699,10 @@ DB_ROW	zbx_db_fetch(DB_RESULT result)
 
 	return result->values;
 #elif defined(HAVE_MYSQL)
-	return mysql_fetch_row(result);
+	if (NULL == result->result)
+		return NULL;
+
+	return (DB_ROW)mysql_fetch_row(result->result);
 #elif defined(HAVE_ORACLE)
 	if (OCI_NO_DATA == (rc = OCIStmtFetch2(result->stmthp, oracle.errhp, 1, OCI_FETCH_NEXT, 0, OCI_DEFAULT)))
 		return NULL;
@@ -1819,10 +1836,9 @@ int	zbx_db_is_null(const char *field)
 	return FAIL;
 }
 
-#if defined(HAVE_IBM_DB2)
-/* in zbxdb.h - #define DBfree_result   IBM_DB2free_result */
-void	IBM_DB2free_result(DB_RESULT result)
+void	DBfree_result(DB_RESULT result)
 {
+#if defined(HAVE_IBM_DB2)
 	if (NULL == result)
 		return;
 
@@ -1844,11 +1860,13 @@ void	IBM_DB2free_result(DB_RESULT result)
 		SQLFreeHandle(SQL_HANDLE_STMT, result->hstmt);
 
 	zbx_free(result);
-}
+#elif defined(HAVE_MYSQL)
+	if (NULL == result)
+		return;
+
+	mysql_free_result(result->result);
+	zbx_free(result);
 #elif defined(HAVE_ORACLE)
-/* in zbxdb.h - #define DBfree_result   OCI_DBfree_result */
-void	OCI_DBfree_result(DB_RESULT result)
-{
 	if (NULL == result)
 		return;
 
@@ -1877,11 +1895,7 @@ void	OCI_DBfree_result(DB_RESULT result)
 		OCIHandleFree((dvoid *)result->stmthp, OCI_HTYPE_STMT);
 
 	zbx_free(result);
-}
 #elif defined(HAVE_POSTGRESQL)
-/* in zbxdb.h - #define DBfree_result   PG_DBfree_result */
-void	PG_DBfree_result(DB_RESULT result)
-{
 	if (NULL == result)
 		return;
 
@@ -1894,11 +1908,7 @@ void	PG_DBfree_result(DB_RESULT result)
 
 	PQclear(result->pg_result);
 	zbx_free(result);
-}
 #elif defined(HAVE_SQLITE3)
-/* in zbxdb.h - #define DBfree_result   SQ_DBfree_result */
-void	SQ_DBfree_result(DB_RESULT result)
-{
 	if (NULL == result)
 		return;
 
@@ -1908,12 +1918,12 @@ void	SQ_DBfree_result(DB_RESULT result)
 	}
 
 	zbx_free(result);
-}
 #endif	/* HAVE_SQLITE3 */
+}
 
 #if defined(HAVE_IBM_DB2)
 /* server status: SQL_CD_TRUE or SQL_CD_FALSE */
-int	IBM_DB2server_status()
+static int	IBM_DB2server_status()
 {
 	int	server_status = SQL_CD_TRUE;
 
@@ -1926,17 +1936,17 @@ int	IBM_DB2server_status()
 	return (SQL_CD_FALSE == server_status ? SQL_CD_TRUE : SQL_CD_FALSE);
 }
 
-int	zbx_ibm_db2_success(SQLRETURN ret)
+static int	zbx_ibm_db2_success(SQLRETURN ret)
 {
 	return (SQL_SUCCESS == ret || SQL_SUCCESS_WITH_INFO == ret ? SUCCEED : FAIL);
 }
 
-int	zbx_ibm_db2_success_ext(SQLRETURN ret)
+static int	zbx_ibm_db2_success_ext(SQLRETURN ret)
 {
 	return (SQL_SUCCESS == ret || SQL_SUCCESS_WITH_INFO == ret || SQL_NO_DATA_FOUND == ret ? SUCCEED : FAIL);
 }
 
-void	zbx_ibm_db2_log_errors(SQLSMALLINT htype, SQLHANDLE hndl, zbx_err_codes_t err, const char *context)
+static void	zbx_ibm_db2_log_errors(SQLSMALLINT htype, SQLHANDLE hndl, zbx_err_codes_t err, const char *context)
 {
 	SQLCHAR		tmp_message[SQL_MAX_MESSAGE_LENGTH + 1], sqlstate[SQL_SQLSTATE_SIZE + 1];
 	char		message[SQL_MAX_MESSAGE_LENGTH + SQL_SQLSTATE_SIZE + 2];
@@ -1964,7 +1974,7 @@ void	zbx_ibm_db2_log_errors(SQLSMALLINT htype, SQLHANDLE hndl, zbx_err_codes_t e
 }
 #elif defined(HAVE_ORACLE)
 /* server status: OCI_SERVER_NORMAL or OCI_SERVER_NOT_CONNECTED */
-ub4	OCI_DBserver_status()
+static ub4	OCI_DBserver_status()
 {
 	sword	err;
 	ub4	server_status = OCI_SERVER_NOT_CONNECTED;
