@@ -18,13 +18,16 @@
 **/
 
 #include <procfs.h>
-
 #include "common.h"
 #include "sysinfo.h"
 #include "zbxregexp.h"
 #include "log.h"
 #include "stats.h"
 
+#if !defined(HAVE_ZONE_H) && defined(HAVE_SYS_UTSNAME_H)
+#	include <sys/utsname.h>
+#endif
+
 extern int	CONFIG_TIMEOUT;
 
 typedef struct
@@ -428,6 +431,48 @@ static int	proc_match_zone(const zbx_sysinfo_proc_t *proc, zbx_uint64_t flags, z
 }
 #endif
 
+#ifndef HAVE_ZONE_H
+/******************************************************************************
+ *                                                                            *
+ * Function: zbx_solaris_version_get                                          *
+ *                                                                            *
+ * Purpose: get Solaris version at runtime                                    *
+ *                                                                            *
+ * Parameters:                                                                *
+ *     major_version - [OUT] major version (e.g. 5)                           *
+ *     minor_version - [OUT] minor version (e.g. 9 for Solaris 9, 10 for      *
+ *                           Solaris 10, 11 for Solaris 11)                   *
+ * Return value:                                                              *
+ *     SUCCEED - no errors, FAIL - an error occurred                          *
+ *                                                                            *
+ ******************************************************************************/
+static int	zbx_solaris_version_get(unsigned int *major_version, unsigned int *minor_version)
+{
+	const char	*__function_name = "zbx_solaris_version_get";
+	int		res;
+	struct utsname	name;
+
+	if (-1 == (res = uname(&name)))
+	{
+		zabbix_log(LOG_LEVEL_WARNING, "%s(): uname() failed: %s", __function_name, zbx_strerror(errno));
+
+		return FAIL;
+	}
+
+	/* expected result in name.release: "5.9" - Solaris 9, "5.10" - Solaris 10, "5.11" - Solaris 11 */
+
+	if (2 != sscanf(name.release, "%u.%u", major_version, minor_version))
+	{
+		zabbix_log(LOG_LEVEL_WARNING, "%s(): sscanf() failed on: \"%s\"", __function_name, name.release);
+		THIS_SHOULD_NEVER_HAPPEN;
+
+		return FAIL;
+	}
+
+	return SUCCEED;
+}
+#endif
+
 /******************************************************************************
  *                                                                            *
  * Function: proc_read_cpu_util                                               *
@@ -617,7 +662,7 @@ void	zbx_proc_get_matching_pids(const zbx_vector_ptr_t *processes, const char *p
 {
 	const char		*__function_name = "zbx_proc_get_matching_pids";
 	struct passwd		*usrinfo;
-	int			ret = FAIL, i;
+	int			i;
 	zbx_sysinfo_proc_t	*proc;
 #ifdef HAVE_ZONE_H
 	zoneid_t		zoneid;
@@ -672,21 +717,39 @@ int	PROC_CPU_UTIL(AGENT_REQUEST *request, AGENT_RESULT *result)
 	zbx_uint64_t	zoneflag;
 	zbx_timespec_t	ts_timeout, ts;
 
-	/* proc.cpu.util[<procname>,<username>,(user|system),<cmdline>,(avg1|avg5|avg15)] */
+#ifndef HAVE_ZONE_H
+	/* this code is for case if agent has been compiled on Solaris 9 or earlier where zones are not supported */
+	/* but the agent is running on a newer Solaris where zones are supported */
+
+#	define ZBX_ZONE_SUPPORT_UNKNOWN	0
+#	define ZBX_ZONE_SUPPORT_YES	1
+#	define ZBX_ZONE_SUPPORT_NO	2
+
+	static int	zone_support = ZBX_ZONE_SUPPORT_UNKNOWN;
+
+	if (ZBX_ZONE_SUPPORT_UNKNOWN == zone_support)
+	{
+		unsigned int	major, minor;
+
+		/* zones are supported in Solaris 10 and later (minimum version is "5.10") */
+
+		if (SUCCEED == zbx_solaris_version_get(&major, &minor) && ((5 == major && 10 <= minor) || 5 < major))
+		{
+			zone_support = ZBX_ZONE_SUPPORT_YES;
+		}
+		else	/* failure to get Solaris version also results in "zones not supported" */
+		{
+			zone_support = ZBX_ZONE_SUPPORT_NO;
+		}
+	}
+#endif
+	/* proc.cpu.util[<procname>,<username>,(user|system),<cmdline>,(avg1|avg5|avg15),(current|all)] */
 	if (6 < request->nparam)
 	{
 		SET_MSG_RESULT(result, zbx_strdup(NULL, "Too many parameters."));
 		return SYSINFO_RET_FAIL;
 	}
 
-#ifndef HAVE_ZONE_H
-	if (5 == request->nparam && GLOBAL_ZONEID != getzoneid())
-	{
-		SET_MSG_RESULT(result, zbx_strdup(NULL, "Unsupported sixth parameter."));
-		return SYSINFO_RET_FAIL;
-	}
-#endif
-
 	/* zbx_procstat_get_* functions expect NULL for default values -       */
 	/* convert empty procname, username and cmdline strings to NULL values */
 	if (NULL != (procname = get_rparam(request, 0)) && '\0' == *procname)
@@ -722,11 +785,11 @@ int	PROC_CPU_UTIL(AGENT_REQUEST *request, AGENT_RESULT *result)
 	{
 		period = SEC_PER_MIN;
 	}
-	else if ( 0 == strcmp(tmp, "avg5"))
+	else if (0 == strcmp(tmp, "avg5"))
 	{
 		period = SEC_PER_MIN * 5;
 	}
-	else if ( 0 == strcmp(tmp, "avg15"))
+	else if (0 == strcmp(tmp, "avg15"))
 	{
 		period = SEC_PER_MIN * 15;
 	}
@@ -738,9 +801,26 @@ int	PROC_CPU_UTIL(AGENT_REQUEST *request, AGENT_RESULT *result)
 
 	if (NULL == (flags = get_rparam(request, 5)) || '\0' == *flags || 0 == strcmp(flags, "current"))
 	{
+#ifndef HAVE_ZONE_H
+		/* agent has been compiled on Solaris 9 or earlier where zones are not supported */
+
+		if (ZBX_ZONE_SUPPORT_YES == zone_support)
+		{
+			/* But now this agent is running on a system with zone support. This agent cannot limit */
+			/* results to only current zone. */
+
+			SET_MSG_RESULT(result, zbx_strdup(NULL, "The sixth parameter value \"current\" cannot be used"
+					" with agent running on a Solaris version with zone support, but compiled on"
+					" a Solaris version without zone support. Consider using \"all\" or install"
+					" agent with Solaris zone support."));
+			return SYSINFO_RET_FAIL;
+		}
+
+		/* zones are not supported, the agent can accept 6th parameter with default value "current" */
+#endif
 		zoneflag = ZBX_PROCSTAT_FLAGS_ZONE_CURRENT;
 	}
-	else if(0 == strcmp(flags, "all"))
+	else if (0 == strcmp(flags, "all"))
 	{
 		zoneflag = ZBX_PROCSTAT_FLAGS_ZONE_ALL;
 	}
